==> jc-1.4.0.tar.gz: soot/util/BafInputRep.h <==
// public class soot.util.BafInputRep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5e9d0095f7d74c0f soot_util_BafInputRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_BafInputRep_H_
#define _JC_soot_util_BafInputRep_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_BafInputRep$object;

// Typedefs
typedef struct _jc_soot_util_BafInputRep$sub_refs	_jc_soot_util_BafInputRep$sub_refs;
typedef struct _jc_soot_util_BafInputRep$sub_nonrefs	_jc_soot_util_BafInputRep$sub_nonrefs;
typedef struct _jc_soot_util_BafInputRep$refs	_jc_soot_util_BafInputRep$refs;
typedef struct _jc_soot_util_BafInputRep$nonrefs	_jc_soot_util_BafInputRep$nonrefs;
typedef struct _jc_soot_util_BafInputRep$object	_jc_soot_util_BafInputRep$object;

typedef const struct _jc_soot_util_BafInputRep$vmethods	_jc_soot_util_BafInputRep$vmethods;
typedef const struct _jc_soot_util_BafInputRep$vtable	_jc_soot_util_BafInputRep$vtable;
typedef const struct _jc_soot_util_BafInputRep$vtype	_jc_soot_util_BafInputRep$vtype;

// Constructors
extern void _jc_soot_util_BafInputRep$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_soot_util_BafInputRep$method$createInputStream$e51fe14db1e6f5a4(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_java_io_InputStream$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_BafInputRep$method$getFileExtension$9afd79be5de4c0cc(_jc_env *, struct _jc_soot_util_BafInputRep$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_BafInputRep$method_info$createInputStream$e51fe14db1e6f5a4;
extern _jc_method _jc_soot_util_BafInputRep$method_info$getFileExtension$9afd79be5de4c0cc;

// Static methods
extern struct _jc_soot_util_BafInputRep$object *_jc_soot_util_BafInputRep$method$v$31e6dcc0bcfa3a83(_jc_env *);

// Virtual methods structure
struct _jc_soot_util_BafInputRep$vmethods {
	struct _jc_java_io_InputStream$object	*(*createInputStream$e51fe14db1e6f5a4)(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_java_io_InputStream$object *);
	struct _jc_java_lang_String$object	*(*getFileExtension$9afd79be5de4c0cc)(_jc_env *, struct _jc_soot_util_BafInputRep$object *);
};

// Vtable
struct _jc_soot_util_BafInputRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_BafInputRep$vmethods	soot_util_BafInputRep;
};

// Vtype
struct _jc_soot_util_BafInputRep$vtype {
	_jc_type			type;
	_jc_soot_util_BafInputRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_BafInputRep$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_BafInputRep$refs {
    _jc_soot_util_BafInputRep$sub_refs	soot_util_BafInputRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_BafInputRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_BafInputRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_BafInputRep$sub_nonrefs	soot_util_BafInputRep;
};

// Object instance structure
struct _jc_soot_util_BafInputRep$object {
	_jc_soot_util_BafInputRep$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_BafInputRep$vtype	*vtype;
	_jc_soot_util_BafInputRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_BafInputRep$vtype _jc_soot_util_BafInputRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_BafInputRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_BafInputRep$class_object;

#endif	/* _JC_soot_util_BafInputRep_H_ */

==> jc-1.4.6.tar.gz: soot/util/BafInputRep.h <==
// public class soot.util.BafInputRep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5e9d0095f7d74c0f soot_util_BafInputRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_BafInputRep_H_
#define _JC_soot_util_BafInputRep_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_BafInputRep$object;

// Typedefs
typedef struct _jc_soot_util_BafInputRep$sub_refs	_jc_soot_util_BafInputRep$sub_refs;
typedef struct _jc_soot_util_BafInputRep$sub_nonrefs	_jc_soot_util_BafInputRep$sub_nonrefs;
typedef struct _jc_soot_util_BafInputRep$refs	_jc_soot_util_BafInputRep$refs;
typedef struct _jc_soot_util_BafInputRep$nonrefs	_jc_soot_util_BafInputRep$nonrefs;
typedef struct _jc_soot_util_BafInputRep$object	_jc_soot_util_BafInputRep$object;

typedef const struct _jc_soot_util_BafInputRep$vmethods	_jc_soot_util_BafInputRep$vmethods;
typedef const struct _jc_soot_util_BafInputRep$vtable	_jc_soot_util_BafInputRep$vtable;
typedef const struct _jc_soot_util_BafInputRep$vtype	_jc_soot_util_BafInputRep$vtype;

// Constructors
extern void _jc_soot_util_BafInputRep$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_soot_util_BafInputRep$method$createInputStream$e51fe14db1e6f5a4(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_BafInputRep$method$getFileExtension$9afd79be5de4c0cc(_jc_env *, struct _jc_soot_util_BafInputRep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_BafInputRep$method_info$createInputStream$e51fe14db1e6f5a4;
extern _jc_method _jc_soot_util_BafInputRep$method_info$getFileExtension$9afd79be5de4c0cc;

// Static methods
extern struct _jc_soot_util_BafInputRep$object *_jc_soot_util_BafInputRep$method$v$31e6dcc0bcfa3a83(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_BafInputRep$vmethods {
	struct _jc_java_io_InputStream$object	*(*createInputStream$e51fe14db1e6f5a4)(_jc_env *, struct _jc_soot_util_BafInputRep$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFileExtension$9afd79be5de4c0cc)(_jc_env *, struct _jc_soot_util_BafInputRep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_BafInputRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_BafInputRep$vmethods	soot_util_BafInputRep;
};

// Vtype
struct _jc_soot_util_BafInputRep$vtype {
	_jc_type			type;
	_jc_soot_util_BafInputRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_BafInputRep$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_BafInputRep$refs {
    _jc_soot_util_BafInputRep$sub_refs	soot_util_BafInputRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_BafInputRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_BafInputRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_BafInputRep$sub_nonrefs	soot_util_BafInputRep;
};

// Object instance structure
struct _jc_soot_util_BafInputRep$object {
	_jc_soot_util_BafInputRep$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_BafInputRep$vtype	*vtype;
	_jc_soot_util_BafInputRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_BafInputRep$vtype _jc_soot_util_BafInputRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_BafInputRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_BafInputRep$class_object;

#endif	/* _JC_soot_util_BafInputRep_H_ */
